@@ -1,5 +1,5 @@
 bma.combine <-
-function (...) {
+function (..., weights = NULL) {
     lis <- list(...)
     classes <- sapply(lis, class)
     if (is.matrix(classes))
@@ -10,12 +10,17 @@ function (...) {
         stop("all objects have to be of the same class.\n")
     K <- length(lis)
     if (all(classes == "survfit.JMbayes")) {    
-        n <- length(lis[[1]]$summaries)
         out <- lis[[1]]
+        n <- length(out$summaries)
+        if (is.null(weights))
+            weights <- rep(1, K)
+        for (i in 1:n) {
+            out$summaries[[i]][, -1] <- out$summaries[[i]][, -1] * weights[1]
+        }
         if (K > 1) {
             for (i in 1:n) {
                 for (k in 2:K) {
-                    out$summaries[[i]][, -1] <- out$summaries[[i]][, -1] + lis[[k]]$summaries[[i]][, -1]
+                    out$summaries[[i]][, -1] <- out$summaries[[i]][, -1] + lis[[k]]$summaries[[i]][, -1] * weights[k]
                 }
             }
         }
